@@ -7,16 +7,23 @@ char   *bcrypt(const char *, const char *);
 VALUE mBCrypt;
 VALUE cBCryptEngine;
 
+/* Define RSTRING_PTR for Ruby 1.8.5, ruby-core's idea of a point release is
+   insane. */
+#ifndef RSTRING_PTR
+#  define    RSTRING_PTR(s)  (RSTRING(s)->ptr)
+#endif
+
 /* Given a logarithmic cost parameter, generates a salt for use with +bc_crypt+.
  */
 static VALUE bc_salt(VALUE self, VALUE cost, VALUE seed) {
-	return rb_str_new2((char *)bcrypt_gensalt(NUM2INT(cost), (u_int8_t *)RSTRING(seed)->ptr));
+	return rb_str_new2((char *)bcrypt_gensalt(NUM2INT(cost), (u_int8_t *)RSTRING_PTR(seed)));
 }
 
 /* Given a secret and a salt, generates a salted hash (which you can then store safely).
  */
 static VALUE bc_crypt(VALUE self, VALUE key, VALUE salt) {
-	return rb_str_new2((char *)bcrypt(RSTRING(key)->ptr, (char *)RSTRING(salt)->ptr));
+	const char * safeguarded = RSTRING_PTR(key) ? RSTRING_PTR(key) : "";
+	return rb_str_new2((char *)bcrypt(safeguarded, (char *)RSTRING_PTR(salt)));
 }
 
 /* Create the BCrypt and BCrypt::Internals modules, and populate them with methods. */
